OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Indlejret besked %s",
    "Important mail" : "Vigtig mail",
    "No message found yet" : "Ingen beskeder fundet endnu",
    "Set up an account" : "Opret en konto",
    "Unread mail" : "Ulæst mail",
    "Important" : "Vigtig",
    "Work" : "Arbejde",
    "Personal" : "Personlig",
    "To Do" : "to do -liste",
    "Later" : "Senere",
    "Mail" : "Mail",
    "You are reaching your mailbox quota limit for {account_email}" : "Du er ved at nå din postkassekvote for {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Du bruger i øjeblikket {percentage} af din postkasseplads. Frigør plads ved at slette unødvendige e-mails.",
    "Mails" : "Mails",
    "Sent date is in the future" : "Afsendelsesdatoen ligger i fremtiden",
    "💌 A mail app for Nextcloud" : "💌 En mail app til Nextcloud",
    "Your session has expired. The page will be reloaded." : "Din session er udløbet. Siden vil blive genindlæst.",
    "Drafts are saved in:" : "Kladder gemmes i:",
    "Sent messages are saved in:" : "Sendte meddelelser gemmes i:",
    "Deleted messages are moved in:" : "Slettede meddelser flyttes til:",
    "Archived messages are moved in:" : "Arkiverede meddelser flyttes til:",
    "Snoozed messages are moved in:" : "Udsatte beskeder flyttes ind:",
    "Junk messages are saved in:" : "Uønsket beskeder gemmes i:",
    "Connecting" : "Tilslutter",
    "Reconnect Google account" : "Gentilslut Google-kontoen",
    "Sign in with Google" : "Log ind med Google",
    "Reconnect Microsoft account" : "Gentilslut Microsoft-konto",
    "Save" : "Gem",
    "Connect" : "Tilslut",
    "Looking up configuration" : "Søger konfiguration",
    "Checking mail host connectivity" : "Kontrollerer mailværtens forbindelse",
    "Configuration discovery failed. Please use the manual settings" : "Opdagelse af konfiguration mislykkedes. Brug venligst de manuelle indstillinger",
    "Password required" : "Adgangskode krævet",
    "Testing authentication" : "Test af autentificering",
    "Awaiting user consent" : "Afventer brugerens samtykke",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Konto oprettet. Følg venligst pop-up-instruktionerne for at linke din Google-konto.",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konto opdateret. Følg venligst pop-up-instruktionerne for at genoprette forbindelsen til din Google-konto.",
    "Account updated" : "Konto opdateret",
    "IMAP server is not reachable" : "IMAP server er ikke tilgængelig",
    "SMTP server is not reachable" : "SMTP server er ikke tilgængelig",
    "IMAP username or password is wrong" : "IMAP brugernavn eller kodeord er forkert",
    "SMTP username or password is wrong" : "SMTP brugernavn eller kodeord er forkert",
    "IMAP connection failed" : "IMAP-forbindelse mislykkedes",
    "SMTP connection failed" : "SMTP-forbindelse mislykkedes",
    "There was an error while setting up your account" : "Der opstod en fejl under opsætning af din konto",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail address" : "Mail adresse",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Indtast venligst en e-mail med formatet navn@eksempel.com",
    "Password" : "Kodeord",
    "Manual" : "Manuel",
    "IMAP Settings" : "IMAP opsætning",
    "IMAP Host" : "IMAP host",
    "IMAP Security" : "IMAP sikkerhed",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP bruger",
    "IMAP Password" : "IMAP kodeord",
    "SMTP Settings" : "SMTP opsætnin",
    "SMTP Host" : "SMTP host",
    "SMTP Security" : "SMTP sikkerhed",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP bruger",
    "SMTP Password" : "SMTP kodeord",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For at din Google-konto skal kunne fungere med denne app, skal du aktivere to-faktor-godkendelse for Gmail samt generere en App-specifik adgangskode.",
    "Account settings" : "Kontoindstillinger",
    "Aliases" : "Aliases",
    "Signature" : "Underskrift",
    "A signature is added to the text of new messages and replies." : "En signatur tilføjes til teksten i nye meddelelser og svar.",
    "Writing mode" : "Skrivestil",
    "Preferred writing mode for new messages and replies." : "Foretrukken skrivemåde for nye meddelelser og svar.",
    "Default folders" : "Standardmapper",
    "Autoresponder" : "Autosvar",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på indgående beskeder. Hvis nogen sender dig flere beskeder, sendes dette automatiske svar højst en gang hver 4. dag.",
    "Filters" : "Filtre",
    "Mail server" : "Mail server",
    "Update alias" : "Opdater alias",
    "Show update alias form" : "Vis formular til opdateringsalias",
    "Delete alias" : "Slet alias",
    "Go back" : "Gå tilbage",
    "Change name" : "Ændre navn",
    "Email address" : "Email adresse",
    "Add alias" : "Tilføj alias",
    "Create alias" : "Opret alias",
    "Cancel" : "Annuller",
    "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
    "Could not update preference" : "Præference kunne ikke opdateres",
    "Mail settings" : "Mail indstillinger",
    "Accounts" : "Konti",
    "Add mail account" : "Tilføj mail konto",
    "General" : "Generelt",
    "List" : "Liste",
    "Sorting" : "Sortering",
    "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
    "Register as application for mail links" : "Registrer som program til at åbne mail links",
    "Register" : "Register",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
    "Trusted senders" : "Betroede afsendere",
    "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
    "Looking for a way to encrypt your emails?" : "Leder du efter en måde at kryptere dine e-mails på?",
    "About" : "Om",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Compose new message" : "Skriv en ny meddelelse",
    "Newer message" : "Nyere besked",
    "Older message" : "Ældre besked",
    "Toggle star" : "Toggle stjerne",
    "Toggle unread" : "Toggle læst",
    "Archive" : "Arkiver",
    "Delete" : "Slet",
    "Search" : "Søg",
    "Send" : "Send",
    "Refresh" : "Opdater",
    "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
    "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
    "Send later" : "Send senere",
    "Message {id} could not be found" : "Beskeden {id} kunne ikke findes",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Signer eller krypter med S/MIME blev valgt, men vi har ikke et certifikat for det valgte alias. Beskeden bliver ikke underskrevet eller krypteret.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Enhver eksisterende formatering (f.eks. fed, kursiv, understregning eller indlejrede billeder) vil blive fjernet.",
    "Turn off formatting" : "Slå formatering fra",
    "Turn off and remove formatting" : "Sluk og fjern formatering",
    "Keep formatting" : "Behold formattering",
    "From" : "Fra",
    "Select account" : "Vælg konto",
    "To" : "Til",
    "Select recipient" : "Vælg modtager",
    "Contact or email address …" : "Kontakt eller email…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Emne",
    "Subject …" : "Emne…",
    "This message came from a noreply address so your reply will probably not be read." : "Denne meddelelse kom fra en svar-ikke adresse. Dit svar vil sansynligvis ikke blive læst. ",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Følgende modtagere har ikke et S/MIME-certifikat: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Følgende modtagere har ikke en PGP nøgle: {recipients}.",
    "Write message …" : "Skriv en besked…",
    "Saving draft …" : "Gemmer kladde…",
    "Error saving draft" : "Fejl ved lagring af kladde",
    "Draft saved" : "Kladde gemt",
    "Save draft" : "Gem kladde",
    "Discard & close draft" : "Kasser og luk kladde",
    "Enable formatting" : "Aktiver formatering",
    "Disable formatting" : "Deaktiver formatering",
    "Upload attachment" : "Upload vedhæftning",
    "Add attachment from Files" : "Vedhæft fra filer",
    "Smart picker" : "Smart Vælger",
    "Request a read receipt" : "Anmod om en læsekvittering",
    "Sign message with S/MIME" : "Underskriv besked med S/MIME",
    "Encrypt message with S/MIME" : "Krypter besked med S/MIME",
    "Encrypt message with Mailvelope" : "Krypter meddelelse med Mailvelope",
    "Send now" : "Send nu",
    "Tomorrow morning" : "I morgen tidlig",
    "Tomorrow afternoon" : "I morgen eftermiddag",
    "Monday morning" : "Mandag morgen",
    "Custom date and time" : "Brugerdefineret dato og tid",
    "Enter a date" : "Indtast en dato",
    "Choose" : "Vælg",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Den vedhæftede fil overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filen via link i stedet.","De vedhæftede filer overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filerne via link i stedet."],
    "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
    "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
    "_{count} attachment_::_{count} attachments_" : ["{count} vedhæftet fil","{count} vedhæftede filer"],
    "Confirm" : "Bekræft",
    "Plain text" : "Klartekst",
    "Rich text" : "Formateret tekst",
    "No messages in this folder" : "Ingen beskeder i denne mappe",
    "No messages" : "Ingen beskeder",
    "Blind copy recipients only" : "Kun blinde kopi-modtagere",
    "No subject" : "Intet emne",
    "Set reminder for later today" : "Sæt påmindelse for senere i dag",
    "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
    "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
    "Set reminder for next week" : "Sæt påmindelse for næste weekend",
    "Could not delete message" : "Kunne ikke slette beskeden",
    "This message is unread" : "Denne besked er ulæst",
    "Unfavorite" : "U-favorit",
    "Favorite" : "Favorit",
    "Unread" : "Ulæst",
    "Read" : "Læst",
    "Unimportant" : "Ikke vigtig",
    "Mark not spam" : "Marker ikke spam",
    "Mark as spam" : "Marker som spam",
    "Edit tags" : "Rediger mærker",
    "Move thread" : "Flyt tråden",
    "Delete thread" : "Slet tråd",
    "Delete message" : "Slet besked",
    "More actions" : "Flere handlinger",
    "Back" : "Tilbage",
    "Edit as new message" : "Rediger som ny besked",
    "Create event" : "Opret begivenhed",
    "Create task" : "Opret opgave",
    "Download message" : "Download besked",
    "Load more" : "Hent flere",
    "_Mark {number} read_::_Mark {number} read_" : ["Marker {number} læst","Marker {number} som læst"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Marker {number} som ulæst","Marker {number} som ulæst"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Marker {number} som vigtigt","Marker {number} som vigtigt"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Marker {number} som uvigtig","Marker {number} som uvigtig"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Fjern foretrukken {number}","Fjern foretrukken {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Favorit {number}","Favoriser {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Fravælg {number}","Fravælg {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Flyt {number} tråd","Flyt {number} tråde"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedhæftet fil","Videresend {number} som vedhæftet fil"],
    "Report this bug" : "Rapporter denne fejl",
    "Event created" : "Begivenhed oprettet",
    "Could not create event" : "Begivenheden kunne ikke oprettes",
    "All day" : "Hele dagen",
    "Description" : "Beskrivelse",
    "Create" : "Opret",
    "This event was updated" : "Denne begivenhed blev opdateret",
    "{attendeeName} accepted your invitation" : "{attendeeName} accepterede din invitation",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} accepterede foreløbigt din invitation",
    "{attendeeName} declined your invitation" : "{attendeeName} afviste din invitation",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reagerede på din invitation",
    "You accepted this invitation" : "Du accepterede denne invitation",
    "You tentatively accepted this invitation" : "Du accepterede foreløbigt denne invitation",
    "You declined this invitation" : "Du afviste denne invitation",
    "You already reacted to this invitation" : "Du har allerede reageret på denne invitation",
    "You have been invited to an event" : "Du er blevet inviteret til en begivenhed",
    "This event was cancelled" : "Denne begivenhed blev aflyst",
    "Save to" : "Gem til",
    "Select" : "Vælg",
    "Comment" : "Kommenter",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "Tentatively accept" : "Accepter foreløbigt",
    "More options" : "Flere muligheder",
    "Remove" : "Fjern",
    "email" : "e-mail",
    "Loading messages …" : "Indlæser beskeder...",
    "Choose target folder" : "Vælg destinationsmappe",
    "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
    "Important info" : "Vigtig information",
    "Other" : "Andet",
    "The sender of this message has asked to be notified when you read this message." : "Afsenderen af denne besked har bedt om at blive underrettet, når du læser denne besked.",
    "Forward" : "Videresend",
    "Move message" : "Flyt besked",
    "Translate" : "Oversæt",
    "Forward message as attachment" : "Videresend besked som vedhæftet fil",
    "View source" : "Vis kildekode",
    "Unnamed" : "Unavngiven",
    "Embedded message" : "Indlejret besked",
    "Choose a folder to store the attachment in" : "Vælg den mappe, som vedhæftningen skal gemmes i",
    "Import into calendar" : "Importér til kalender",
    "Download attachment" : "Hent vedhæftning",
    "Save to Files" : "Gem til filer",
    "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
    "Save all to Files" : "Gem alle filer",
    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte dit privatliv.",
    "Show images" : "Vis billeder",
    "Always show images from {sender}" : "Altid vis billeder fra {sender}",
    "Always show images from {domain}" : "Altid vis billeder fra {domain}",
    "Quoted text" : "Citeret tekst",
    "Move" : "Flyt",
    "Moving" : "Flytter",
    "Moving thread" : "Flytter tråd",
    "Moving message" : "Flytter besked",
    "Remove account" : "Fjern konto",
    "Remove {email}" : "Fjern {email}",
    "Add folder" : "Tilføj mappe",
    "Folder name" : "Mappenavn",
    "Saving" : "Gemmer",
    "Move up" : "Flyt op",
    "Move down" : "Flyt ned",
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Fold mapper sammen",
    "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
    "Loading …" : "Indlæser…",
    "Clear mailbox {name}" : "Ryd postkasse {name}",
    "Delete folder" : "Slet mappe",
    "Mark all as read" : "Markér alle som læst",
    "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
    "Add subfolder" : "Tilføj undermappe",
    "Rename" : "Omdøb",
    "Move folder" : "Flyt mappe",
    "Clear cache" : "Ryd cache",
    "Subscribed" : "Abonneret",
    "Sync in background" : "Synkroniser i baggrunden",
    "Outbox" : "Udbakke",
    "New message" : "Ny besked",
    "Draft" : "Kladde",
    "Reply" : "Besvar",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
    "Error sending your message" : "Fejl ved afsendelse af din besked",
    "Retry" : "Prøv igen",
    "Warning sending your message" : "Advarsel om at sende din besked",
    "Send anyway" : "Send alligevel",
    "Welcome to {productName} Mail" : "Velkommen til {productName} mail",
    "Start writing a message by clicking below or select an existing message to display its contents" : "Begynd at skrive en besked ved at klikke nedenfor eller vælg en eksisterende besked for at få vist dens indhold",
    "First day" : "Første dag",
    "Message" : "Besked",
    "Could not open outbox" : "Kunne ikke åbne udbakken",
    "New Contact" : "Ny kontakt",
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Add" : "Tilføj",
    "Show less" : "Vis mindre",
    "Clear" : "Ryd",
    "Close" : "Luk",
    "Search parameters" : "Søgeparametre",
    "Body" : "Krop",
    "Date" : "Dato",
    "Pick a start date" : "Vælg en startdato",
    "Pick an end date" : "Vælg en slutdato",
    "Tags" : "Tags",
    "Select tags" : "Vælg tags",
    "Marked as" : "Markeret som",
    "Has attachments" : "Har vedhæftede filer",
    "Mentions me" : "Omtalte mig",
    "Last 7 days" : "Sidste 7 dage",
    "Sieve credentials" : "Sieve legitimationsoplysninger",
    "IMAP credentials" : "IMAP legitimationsoplysninger",
    "Custom" : "Brugerdefineret",
    "Signature …" : "Underskrift …",
    "Save signature" : "Gem underskrift",
    "Message source" : "Beskedens kildekode",
    "Saving new tag name …" : "Gemmer nyt tag navn ...",
    "Tag already exists" : "Mærket eksisterer allerede",
    "Add tag" : "Tilføj Tag",
    "Loading thread" : "Indlæser tråd",
    "Not found" : "Ikke fundet",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME-signatur. Meddelelsen er ikke ændret, siden den blev sendt.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
    "Reply all" : "Besvar alle",
    "Reply to sender only" : "Besvar kun afsender",
    "Mark as unread" : "Markér som ulæst",
    "Mark as read" : "Markér som læst",
    "Go to newest message" : "Gå til nyeste besked",
    "Translate from" : "Oversæt fra",
    "Translate to" : "Oversæt til",
    "Copy translated text" : "Kopiér oversat tekst",
    "Untitled event" : "Unavngiven begivenhed",
    "(organizer)" : "(arrangør)",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
    "Airplane" : "Fly",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
    "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
    "Train" : "Tog",
    "Recipient" : "Modtager",
    "New filter" : "Nyt filter",
    "Operator" : "Operatør",
    "contains" : "indeholder",
    "matches" : "er lig med",
    "Priority" : "Prioritet",
    "Reset" : "Nulstil",
    "Client ID" : "Klient ID",
    "Client secret" : "Klienthemmelighed",
    "IMAP" : "IMAP",
    "User" : "Bruger",
    "Host" : "Vært",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Failed to import the certificate. Please check the password." : "Kunne ikke importere certifikatet. Tjek venligst adgangskoden.",
    "Certificate imported successfully" : "Certifikatet blev importeret",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Kunne ikke importere certifikatet. Sørg for, at den private nøgle matcher certifikatet og ikke er beskyttet af en kode.",
    "Failed to import the certificate" : "Kunne ikke importere certifikatet",
    "S/MIME certificates" : "S/MIME certifikater",
    "Certificate name" : "Certifikatnavn",
    "E-mail address" : "E-mail adresse",
    "Valid until" : "Gyldig indtil",
    "Delete certificate" : "Slet certifikat",
    "No certificate imported yet" : "Intet certifikat importeret endnu",
    "Import certificate" : "Importér certifikat",
    "Import S/MIME certificate" : "Importer S/MIME-certifikat",
    "PKCS #12 Certificate" : "PKCS #12 Certifikat",
    "PEM Certificate" : "PEM Certifikat",
    "Certificate" : "Certifikat",
    "Private key (optional)" : "Privat nøgle (valgfrit)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøgle er kun påkrævet, hvis du har til hensigt at sende signerede og krypterede e-mails ved hjælp af dette certifikat.",
    "Submit" : "Send",
    "Account connected" : "Kontoen er tilknyttet",
    "Connect your mail account" : "Forbind din mail konto",
    "All" : "Alle",
    "Drafts" : "Udkast",
    "Favorites" : "Favoritter",
    "Priority inbox" : "Prioriteret indbakke",
    "All inboxes" : "Alle indbakker",
    "Inbox" : "Indbakke",
    "Junk" : "Junk",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "Error while sharing file" : "Fejl ved deling af fil",
    "{from}\n{subject}" : "{fra}\n{emne}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny besked \nfra {from}","%n nye beskeder \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Discard changes" : "Fortryd ændringer",
    "Message sent" : "Beskeden blev sendt",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
    "Could not load your message" : "Din besked kunne ikke indlæses",
    "Could not load the desired message" : "Den ønskede besked kunne ikke indlæses",
    "Could not load the message" : "Beskeden kunne ikke indlæses",
    "Error loading message" : "Fejl under indlæsning af besked",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
    "Redirect" : "Omdiriger",
    "The link leads to %s" : "Linket fører til %s",
    "Continue to %s" : "Videre til %s",
    "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
    "Draft: " : "Kladde:",
    "Could not open mailbox" : "Postkassen kunne ikke åbnes",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
    "Choose target mailbox" : "Vælg målpostkasse",
    "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
    "Add mailbox" : "Tilføj postkasse",
    "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
    "Show all mailboxes" : "Vis alle postkasser",
    "Collapse mailboxes" : "Skjul postkasser ",
    "Clear mailbox" : "Ryd postkasse",
    "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
    "Add submailbox" : "Tilføj underpostkasse",
    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
    "Search in mailbox" : "Søg i postkasse",
    "New test" : "Nyeste test",
    "Actions" : "Handlinger",
    "New action" : "Ny handling"
},
"nplurals=2; plural=(n != 1);");
